You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@stanbol.apache.org by si...@apache.org on 2012/03/15 17:00:41 UTC

svn commit: r1301063 - in /incubator/stanbol/trunk/contenthub/ldpath/src/main: java/org/apache/stanbol/contenthub/ldpath/solr/LDPathUtils.java resources/solr/core/template.zip

Author: sinaci
Date: Thu Mar 15 16:00:41 2012
New Revision: 1301063

URL: http://svn.apache.org/viewvc?rev=1301063&view=rev
Log:
Bug fix in LDpath of Contenthub.

Modified:
    incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/LDPathUtils.java
    incubator/stanbol/trunk/contenthub/ldpath/src/main/resources/solr/core/template.zip

Modified: incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/LDPathUtils.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/LDPathUtils.java?rev=1301063&r1=1301062&r2=1301063&view=diff
==============================================================================
--- incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/LDPathUtils.java (original)
+++ incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/LDPathUtils.java Thu Mar 15 16:00:41 2012
@@ -78,6 +78,7 @@ public class LDPathUtils {
     private static final String SOLR_TEMPLATE_ZIP = SOLR_TEMPLATE_NAME + ".zip";
     private static final String SOLR_TEMPLATE_SCHEMA = SOLR_TEMPLATE_NAME + "/conf/schema-template.xml";
     private static final String SOLR_SCHEMA = "/conf/schema.xml";
+    private static final String SOLR_ALLTEXT_FIELD = "stanbolreserved_text_all";
 
     private static final int BUFFER_SIZE = 8024;
 
@@ -298,7 +299,7 @@ public class LDPathUtils {
      * the program is also set if it is included in {@link LDPathUtils#SOLR_FIELD_OPTIONS}. Another
      * configuration about the fields obtained from the program is {@link LDPathUtils#SOLR_COPY_FIELD_OPTION}.
      * If there is a specified configuration about this field, <b>destination</b> of <b>copyField</b> element
      * is set accordingly. Otherwise, the destination is set as <b>text_all</b>
      * 
      * @param program
      *            LDPath program of which fields will be obtained
@@ -371,7 +372,7 @@ public class LDPathUtils {
                 } else {
                     Element copyElement = new Element("copyField");
                     copyElement.addAttribute(new Attribute("source", fieldName));
-                    copyElement.addAttribute(new Attribute("dest", "text_all"));
+                    copyElement.addAttribute(new Attribute("dest", SOLR_ALLTEXT_FIELD));
                     schemaNode.appendChild(copyElement);
                 }
 
@@ -298,7 +299,7 @@ public class LDPathUtils {
      * configuration about the fields obtained from the program is {@link LDPathUtils#SOLR_COPY_FIELD_OPTION}.
      * If there is a specified configuration about this field, <b>destination</b> of <b>copyField</b> element
-     * is set accordingly. Otherwise, the destination is set as <b>text_all</b>
+     * is set accordingly. Otherwise, the destination is set as <b>stanbolreserved_text_all</b>
      * 
      * @param program

Modified: incubator/stanbol/trunk/contenthub/ldpath/src/main/resources/solr/core/template.zip
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/contenthub/ldpath/src/main/resources/solr/core/template.zip?rev=1301063&r1=1301062&r2=1301063&view=diff
==============================================================================
Binary files - no diff available.